==> adx-center-api-0.0.2-sources.jar: cn/com/duiba/tuia/adx/center/api/dto/ResourceIdeaCrowdBindDto.java <==
package cn.com.duiba.tuia.adx.center.api.dto;

import java.io.Serializable;

public class ResourceIdeaCrowdBindDto implements Serializable {

    /**
     * 人群包ID
     */
    private Long crowdId;

    /**
     * 人群包名称
     */
    private String crowdName;

    /**
     * 人群包类型: 1私有人群包，2行业人群包
     */
    private Integer crowdType;

    /**
     * 人群类型名称
     */
    private String crowdTypeName;

    /**
     * 广告主id
     */
    private Long accountId;

    /**
     * 使用场景
     */
    private Integer algScene;

    /**
     * 人群数量：展示人群包今日的deviceid的总量 默认"-"
     */
    private String crowdCount="-";

    /**
     * 人群包创建时间
     */
    private String createTime;

    /**
     * 人群包创建时间
     */
    private String modifyTime;

    public Long getCrowdId() {
        return crowdId;
    }

    public void setCrowdId(Long crowdId) {
        this.crowdId = crowdId;
    }

    public String getCrowdName() {
        return crowdName;
    }

    public void setCrowdName(String crowdName) {
        this.crowdName = crowdName;
    }

    public Integer getCrowdType() {
        return crowdType;
    }

    public void setCrowdType(Integer crowdType) {
        this.crowdType = crowdType;
    }

    public String getCrowdTypeName() {
        return crowdTypeName;
    }

    public void setCrowdTypeName(String crowdTypeName) {
        this.crowdTypeName = crowdTypeName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getAlgScene() {
        return algScene;
    }

    public void setAlgScene(Integer algScene) {
        this.algScene = algScene;
    }

    public String getCrowdCount() {
        return crowdCount;
    }

    public void setCrowdCount(String crowdCount) {
        this.crowdCount = crowdCount;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(String modifyTime) {
        this.modifyTime = modifyTime;
    }

    @Override
    public String toString() {
        return "ResourceLocationCrowdBindDto{" +
                "crowdId=" + crowdId +
                ", crowdName='" + crowdName + '\'' +
                ", crowdType=" + crowdType +
                ", crowdTypeName='" + crowdTypeName + '\'' +
                ", accountId=" + accountId +
                ", algScene=" + algScene +
                ", crowdCount='" + crowdCount + '\'' +
                ", createTime='" + createTime + '\'' +
                ", modifyTime='" + modifyTime + '\'' +
                '}';
    }
}

==> adx-center-api-0.1.44-20250815.055039-6-sources.jar: cn/com/duiba/tuia/adx/center/api/dto/ResourceIdeaCrowdBindDto.java <==
package cn.com.duiba.tuia.adx.center.api.dto;

import java.io.Serializable;

public class ResourceIdeaCrowdBindDto implements Serializable {

    /**
     * 人群包ID
     */
    private Long crowdId;

    /**
     * 人群包新id
     */
    private String crowNewId;

    /**
     * 人群包名称
     */
    private String crowdName;

    /**
     * 人群包类型: 1私有人群包，2行业人群包
     */
    private Integer crowdType;

    /**
     * 人群类型名称
     */
    private String crowdTypeName;

    /**
     * 广告主id
     */
    private Long accountId;

    /**
     * 使用场景
     */
    private Integer algScene;

    /**
     * 人群数量：展示人群包今日的deviceid的总量 默认"-"
     */
    private String crowdCount="-";

    /**
     * 人群包创建时间
     */
    private String createTime;

    /**
     * 人群包创建时间
     */
    private String modifyTime;

    public Long getCrowdId() {
        return crowdId;
    }

    public void setCrowdId(Long crowdId) {
        this.crowdId = crowdId;
    }

    public String getCrowNewId() {
        return crowNewId;
    }

    public void setCrowNewId(String crowNewId) {
        this.crowNewId = crowNewId;
    }

    public String getCrowdName() {
        return crowdName;
    }

    public void setCrowdName(String crowdName) {
        this.crowdName = crowdName;
    }

    public Integer getCrowdType() {
        return crowdType;
    }

    public void setCrowdType(Integer crowdType) {
        this.crowdType = crowdType;
    }

    public String getCrowdTypeName() {
        return crowdTypeName;
    }

    public void setCrowdTypeName(String crowdTypeName) {
        this.crowdTypeName = crowdTypeName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getAlgScene() {
        return algScene;
    }

    public void setAlgScene(Integer algScene) {
        this.algScene = algScene;
    }

    public String getCrowdCount() {
        return crowdCount;
    }

    public void setCrowdCount(String crowdCount) {
        this.crowdCount = crowdCount;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(String modifyTime) {
        this.modifyTime = modifyTime;
    }

    @Override
    public String toString() {
        return "ResourceIdeaCrowdBindDto{" +
                "crowdId=" + crowdId +
                ", crowNewId='" + crowNewId + '\'' +
                ", crowdName='" + crowdName + '\'' +
                ", crowdType=" + crowdType +
                ", crowdTypeName='" + crowdTypeName + '\'' +
                ", accountId=" + accountId +
                ", algScene=" + algScene +
                ", crowdCount='" + crowdCount + '\'' +
                ", createTime='" + createTime + '\'' +
                ", modifyTime='" + modifyTime + '\'' +
                '}';
    }
}
